import json
import os
import time
import argparse

def open_face_processing(files_list_path,write_file_path):
    path = "/opt/openface-20220208/"
    os.chdir(path)
    count = 0
    for file in os.listdir(files_list_path):
        if file.endswith(".mp4"):
            print("#####################"+str(file)+"#################")
            print(count)
            file_path = os.path.join(files_list_path,file)
            file_write_path = os.path.join(write_file_path,file.split(".")[0])
            if not os.path.exists(file_write_path):
                os.mkdir(file_write_path)
            print(file_write_path+"/")
            path_exe = "./FaceLandmarkVidMulti -f "+ str(file_path)+" -out_dir "+ str(file_write_path)+"/"
            print(path_exe)
            os.system(path_exe)
            count = count + 1
            time.sleep(10)




from test_package import open_face_processing

def process_arguments():
    parser = argparse.ArgumentParser()
    parser.add_argument("--video_folder_read_path",
                        help="Pass the folder containing all video files to read", type=str)
    parser.add_argument("--write_path_file_path",
                        help="save the outcomes of open face in this path", type=str)
    #parser.add_argument("--path",
    #                    help="Pass the first timestamp at the starting point of the video",
    #                    type=float)
    args = parser.parse_args()
    video_folder_read_path = args.video_file_read_path
    write_path_file_path = args.write_path_file_path
    #first_linux_time_stamp = args.first_time_stamp_info
    open_face_processing(video_folder_read_path, write_path_file_path)



import setuptools

with open("README.md", "r") as fh:
    description = fh.read()

setuptools.setup(
    name="test_package_open_face",
    version="0.0.1",
    author="pargim",
    author_email="mohan.tita@gmail.com",
    packages=["test_package_open_face"],
    description="A sample test package",
    long_description=description,
    long_description_content_type="text/markdown",
    url="https://github.com/mohankashyap/test-tackage",
    license='MIT',
    python_requires='>=3.6',
    install_requires=[]
)
